@@ -82,7 +82,7 @@ sub awx_wx_config_data {
     my $self = shift;
     my $wxdir_b = $ENV{WXDIR};
     my $wxdir = $self->notes( 'build_wx' ) ?
-      awx_install_arch_dir( 'rEpLaCe' ) : $wxdir_b;
+      awx_install_arch_dir( $self, 'rEpLaCe' ) : $wxdir_b;
 
     return { 'wxdir'       => $wxdir,
              'wxdir_build' => $wxdir_b,
@@ -98,7 +98,7 @@ sub awx_configure {
 
     $config{prefix} = $self->wx_config( 'wxdir' );
     $config{config}{toolkit} = $self->is_wince ? 'wce' : 'msw';
-    $config{shared_library_path} = awx_install_arch_file( "rEpLaCe/lib" );
+    $config{shared_library_path} = awx_install_arch_file( $self, "rEpLaCe/lib" );
 
     die "Unable to find setup.h directory"
       unless $self->wx_config( 'cxxflags' )
@@ -152,17 +152,21 @@ sub files_to_install {
         $files{$lib} = awx_arch_file( "rEpLaCe/lib/$base" );
     }
 
-    if( $self->notes( 'build_wx' ) ) {
+    if( $self->notes( 'build_wx' ) || $self->notes( 'mk_portable' )  ) {
         require File::Find;
         my $no_platform = join '|', qw(unix gtk x11 motif mac cocoa
-                                       os2 palmos univ mgl msdos);
+                                       os2 palmos univ mgl msdos gtk1
+                                       dfb);
         my $wx_base = $self->awx_wx_config_data->{wxdir_build};
         foreach my $find_base ( File::Spec->catdir( $wx_base, qw(include wx) ),
                              File::Spec->catdir( $wx_base, qw(contrib
                                                  include wx) ) ) {
+            next unless -d $find_base;
             my $wanted = sub {
-                $File::Find::prune =
+                $File::Find::prune ||=
                   -d $_ && $_ =~ m{include[/\\]wx[/\\](?:$no_platform)$};
+                $File::Find::prune ||=
+                  -d $_ && $_ =~ m{[/\\]\.svn$};
                 return unless -f $_;
                 my $rel = File::Spec->abs2rel( $_, $find_base );
                 $files{$_} = awx_arch_file( "rEpLaCe/include/wx/$rel" );
@@ -204,7 +208,7 @@ sub awx_get_package {
     return 'WinCE' if $INC{'Cross.pm'};
 
     SWITCH: {
-        local $_ = $Config{cc};
+        local $_ = $Config{ccname};
 
         /^cl/i  and $package = 'Win32_MSVC'  and last SWITCH;
         /^gcc/i and $package = 'Win32_MinGW' and last SWITCH;
